@@ -3,7 +3,7 @@ BEGIN {
   $Package::Stash::PP::AUTHORITY = 'cpan:DOY';
 }
 {
-  $Package::Stash::PP::VERSION = '0.35';
+  $Package::Stash::PP::VERSION = '0.36';
 }
 use strict;
 use warnings;
@@ -87,10 +87,6 @@ sub namespace {
     }
 }
 
-sub _is_anon {
-    return !defined $_[0]->{package};
-}
-
 {
     my %SIGIL_MAP = (
         '$' => 'SCALAR',
@@ -101,7 +97,7 @@ sub _is_anon {
     );
 
     sub _deconstruct_variable_name {
-        my ($self, $variable) = @_;
+        my ($variable) = @_;
 
         my @ret;
         if (ref($variable) eq 'HASH') {
@@ -132,7 +128,6 @@ sub _is_anon {
 }
 
 sub _valid_for_type {
-    my $self = shift;
     my ($value, $type) = @_;
     if ($type eq 'HASH' || $type eq 'ARRAY'
      || $type eq 'IO'   || $type eq 'CODE') {
@@ -147,10 +142,10 @@ sub _valid_for_type {
 sub add_symbol {
     my ($self, $variable, $initial_value, %opts) = @_;
 
-    my ($name, $sigil, $type) = $self->_deconstruct_variable_name($variable);
+    my ($name, $sigil, $type) = _deconstruct_variable_name($variable);
 
     if (@_ > 2) {
-        $self->_valid_for_type($initial_value, $type)
+        _valid_for_type($initial_value, $type)
             || confess "$initial_value is not of type $type";
 
         # cheap fail-fast check for PERLDBf_SUBLINE and '&'
@@ -181,7 +176,7 @@ sub add_symbol {
                 *{ $self->name . '::' . $name };
             }
             else {
-                my $undef = $self->_undef_ref_for_type($type);
+                my $undef = _undef_ref_for_type($type);
                 *{ $self->name . '::' . $name } = $undef;
             }
         }
@@ -205,13 +200,12 @@ sub add_symbol {
         }
         else {
             return if BROKEN_ISA_ASSIGNMENT && $name eq 'ISA';
-            *{ $namespace->{$name} } = $self->_undef_ref_for_type($type);
+            *{ $namespace->{$name} } = _undef_ref_for_type($type);
         }
     }
 }
 
 sub _undef_ref_for_type {
-    my $self = shift;
     my ($type) = @_;
 
     if ($type eq 'ARRAY') {
@@ -242,7 +236,7 @@ sub remove_glob {
 sub has_symbol {
     my ($self, $variable) = @_;
 
-    my ($name, $sigil, $type) = $self->_deconstruct_variable_name($variable);
+    my ($name, $sigil, $type) = _deconstruct_variable_name($variable);
 
     my $namespace = $self->namespace;
 
@@ -275,7 +269,7 @@ sub has_symbol {
 sub get_symbol {
     my ($self, $variable, %opts) = @_;
 
-    my ($name, $sigil, $type) = $self->_deconstruct_variable_name($variable);
+    my ($name, $sigil, $type) = _deconstruct_variable_name($variable);
 
     my $namespace = $self->namespace;
 
@@ -295,7 +289,7 @@ sub get_symbol {
     }
     else {
         if ($type eq 'CODE') {
-            if (BROKEN_GLOB_ASSIGNMENT || !$self->_is_anon) {
+            if (BROKEN_GLOB_ASSIGNMENT || defined($self->{package})) {
                 no strict 'refs';
                 return \&{ $self->name . '::' . $name };
             }
@@ -329,7 +323,7 @@ sub get_or_add_symbol {
 sub remove_symbol {
     my ($self, $variable) = @_;
 
-    my ($name, $sigil, $type) = $self->_deconstruct_variable_name($variable);
+    my ($name, $sigil, $type) = _deconstruct_variable_name($variable);
 
     # FIXME:
     # no doubt this is grossly inefficient and
@@ -429,7 +423,7 @@ Package::Stash::PP - pure perl implementation of the Package::Stash API
 
 =head1 VERSION
 
-version 0.35
+version 0.36
 
 =head1 SYNOPSIS
 
